@@ -3,6 +3,7 @@ import datetime
 import htmlgenerator as hg
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.db import models
+from django.http import HttpResponseNotFound
 from django.shortcuts import get_object_or_404
 from django.urls import path
 from django.utils.translation import gettext_lazy as _
@@ -12,7 +13,7 @@ from bread import formatters
 from bread import layout as _layout
 from bread import menu, views
 from bread.utils import filter_fieldlist, generate_excel, urls, xlsxresponse
-from bread.utils.links import Link
+from bread.utils.links import Link, ModelHref
 from bread.views.browse import delete
 from bread.views.edit import bulkcopy
 
@@ -66,6 +67,13 @@ class ReadView(views.ReadView):
 
         # ordering, copied from bread.views.browse.BrowseView.get_queryset
         qs = self.object.queryset
+        if not qs:
+            return _layout.notification.InlineNotification(
+                "Error",
+                f"Model '{self.object.model}' does no longer exist.",
+                kind="error",
+            )
+
         order = self.request.GET.get("ordering")
         if order:
             if order.endswith("__int"):
@@ -106,18 +114,16 @@ class ReadView(views.ReadView):
         ).with_toolbar(
             title=self.object.name,
             helper_text=f"{self.object.queryset.count()} {self.object.model.model_class()._meta.verbose_name_plural}",
-            primary_button=_layout.button.Button.fromaction(
-                Link(
-                    urls.reverse_model(self.object, "excel", {"pk": self.object.pk}),
-                    label=_("Excel"),
-                    iconname="download",
-                )
-            ),
+            primary_button=_layout.button.Button(
+                label=_("Excel"), icon="download"
+            ).as_href(ModelHref(self.object, "excel")),
         )
 
 
 def exceldownload(request, pk: int):
     report = get_object_or_404(Report, pk=pk)
+    if report.model.model_class() is None:
+        return HttpResponseNotFound()
 
     columns = {
         column.name: lambda row, c=column.column: formatters.format_value(
@@ -161,25 +167,13 @@ urlpatterns = [
                 ),
             ],
             rowactions=[
-                menu.Action(
-                    js=hg.BaseElement(
-                        "document.location = '",
-                        hg.F(lambda c: _layout.objectaction(c["row"], "edit")),
-                        "'",
-                    ),
+                Link(
+                    href=ModelHref(Report, "edit", kwargs={"pk": hg.C("row.pk")}),
                     iconname="edit",
                     label=_("Edit"),
                 ),
-                menu.Action(
-                    js=hg.BaseElement(
-                        "document.location = '",
-                        hg.F(
-                            lambda c: urls.reverse_model(
-                                Report, "excel", kwargs={"pk": c["row"].pk}
-                            )
-                        ),
-                        "'",
-                    ),
+                Link(
+                    href=ModelHref(Report, "excel", kwargs={"pk": hg.C("row.pk")}),
                     iconname="download",
                     label=_("Excel"),
                 ),
