@@ -1,4 +1,4 @@
-from typing import Callable, NamedTuple, Optional
+from typing import Callable, List, NamedTuple, Optional
 
 import htmlgenerator as hg
 from django.conf import settings
@@ -15,7 +15,6 @@ from guardian.mixins import PermissionListMixin
 from bread.utils import expand_ALL_constant, filter_fieldlist
 
 from .. import layout as _layout  # prevent name clashing
-from ..layout.base import fieldlabel
 from ..utils import (
     generate_excel,
     link_with_urlparameters,
@@ -31,7 +30,7 @@ class BulkAction(NamedTuple):
     label: str
     action: Callable[[HttpRequest, models.query.QuerySet], Optional[HttpResponse]]
     iconname: str = "fade"
-    permissions: list[str] = []
+    permissions: List[str] = []
 
     def has_permission(self, request, obj=None):
         return all(
@@ -237,12 +236,15 @@ def export(queryset, columns):
             )
         if isinstance(column, str):
             column = _layout.datatable.DataTableColumn(
-                fieldlabel(queryset.model, column), hg.C(f"row.{column}")
+                _layout.ObjectFieldLabel(column, "model"),
+                _layout.ObjectFieldValue(column, "row"),
             )
 
-        columndefinitions[column.header] = lambda row, column=column: hg.render(
-            hg.BaseElement(column.cell), {"row": row}
-        )
+            columndefinitions[
+                hg.render(hg.BaseElement(column.header), {"model": queryset.model})
+            ] = lambda row, column=column: hg.render(
+                hg.BaseElement(column.cell), {"row": row}
+            )
 
     workbook = generate_excel(queryset, columndefinitions)
     workbook.title = pretty_modelname(queryset.model)
